@@ -1,6 +1,6 @@
 package Catalyst::View::BasePerRequest;
 
-our $VERSION = '0.003';
+our $VERSION = '0.004';
 our $DEFAULT_FACTORY = 'Catalyst::View::BasePerRequest::Factory';
 
 use Moose;
@@ -105,10 +105,7 @@ sub get_rendered {
   return $self->flatten_rendered_for_response_body(@rendered);
 }
 
-sub flatten_rendered_for_response_body {
-  my ($self, @rendered) = @_;
-  return join '', grep { defined($_) } @rendered;
-}
+sub flatten_rendered_for_response_body { return shift->flatten_rendered(@_) }
 
 sub render_error_class { 'Catalyst::View::BasePerRequest::Exception::RenderError' }
 
@@ -136,7 +133,8 @@ sub render_code {
     Scalar::Util::blessed($_) && $_->can('get_rendered') ? $_->get_rendered : $_;
   }  $self->code->($self->prepare_render_code_args);
 
-  my $flat = $self->flatten_rendered_for_response_body(@inner);
+  my $flat = $self->flatten_rendered_for_inner_content
+  (@inner);
   return $flat;
 }
 
@@ -145,6 +143,13 @@ sub prepare_render_code_args {
   return $self;
 }
 
+sub flatten_rendered_for_inner_content { return shift->flatten_rendered(@_) }
+
+sub flatten_rendered {
+  my $self = shift;
+  return join '', grep { defined($_) } @_;
+}
+
 sub content {
   my ($self, $name) = @_;
   return exists($self->ctx->stash->{view_blocks}{$name}) ? 
@@ -155,12 +160,14 @@ sub content {
 sub render_content_value {
   my $self = shift;
   if((ref($_[0])||'') eq 'CODE') {
-    return $self->flatten_rendered_for_response_body($_[0]->($_[1]));
+    return $self->flatten_rendered_for_content_blocks($_[0]->($_[1]));
   } else {
-    return $self->flatten_rendered_for_response_body(@_);
+    return $self->flatten_rendered_for_content_blocks(@_);
   }
 }
 
+sub flatten_rendered_for_content_blocks { return shift->flatten_rendered(@_) }
+
 sub content_for {
   my ($self, $name, $value) = @_;
   Module::Runtime::use_module($self->_content_exception_class)
